%define anolis_release 2

%bcond_without libssh2

Summary:        C implementation of the Git core methods as a library with a solid API
Name:           libgit2
Version:        1.5.1
Release:        %{anolis_release}%{?dist}
License:        GPLv2 with exceptions
URL:            https://libgit2.org/
Source0:        https://github.com/%{name}/%{name}/archive/refs/tags/v%{version}.tar.gz

# Skip online tests to avoid network access
Patch1001:      1001-skipping-online-tests.patch

BuildRequires:  cmake >= 3.5.1 gcc ninja-build
BuildRequires:  python3
BuildRequires:  http-parser-devel
BuildRequires:  libcurl-devel
%if %{with libssh2}
BuildRequires:  libssh2-devel
%endif
BuildRequires:  openssl-devel
BuildRequires:  pcre2-devel
BuildRequires:  zlib-devel

Provides:       bundled(libxdiff)

%description
libgit2 is a portable, pure C implementation of the Git core methods
provided as a re-entrant linkable library with a solid API, allowing
to build Git functionality into your application. Language bindings
like Rugged (Ruby), LibGit2Sharp (.NET), pygit2 (Python) and NodeGit
(Node) allow you to build Git tooling in your favorite language.

%package        devel
Summary:        Development libraries and header files for %{name}
Requires:       %{name} = %{version}-%{release}

%description    devel
This package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:   Doc files for %{name}
Requires:  %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
This package contains documentation for %{name}.

%prep
%autosetup -p1

# Remove libraries that are provided by BuildRequires part.
# They don't need to be bundled.
rm -vr deps

%build
%cmake \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DREGEX_BACKEND=pcre2 \
  -DUSE_HTTP_PARSER=system \
  -DUSE_HTTPS=OpenSSL \
  -DUSE_NTLMCLIENT=OFF \
  -DUSE_SHA1=HTTPS \
%if %{without libssh2}
  -DUSE_SSH=OFF \
%endif
  -GNinja

%cmake_build

%install
%cmake_install

%generate_compatibility_deps

%check
%ctest

%files
%license COPYING
%{_bindir}/git2_cli
%{abidir}/git2_cli-option.list
%{_libdir}/libgit2.so.1.5*
%{abidir}/libgit2*.dump

%files devel
%doc examples
%{_libdir}/libgit2.so
%{_libdir}/pkgconfig/libgit2.pc
%{_includedir}/git2.h
%{_includedir}/git2/

%files doc
%doc AUTHORS docs README.md SECURITY.md

%changelog
* Mon Apr 10 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.5.1-2
- optimize spec file
- add patch to skip online tests

* Sun Jan 22 2023 Funda Wang <fundawang@yeah.net> - 1.5.1-1
- New version 1.5.1

* Mon Dec 19 2022 Funda Wang <fundawang@yeah.net> - 1.5.0-1
- New version 1.5.0

* Tue Jul 12 2022 happy_orange <songnannan@linux.alibaba.com> - 1.3.1-1
- Init pcakage from upstream
